# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-07-03 11:20
from __future__ import unicode_literals

from django.db import migrations

from os.path import dirname, join


def load_views():
    script_path = dirname(__file__)
    with open(join(script_path, '../support/views.sql')) as stmts:
        return stmts.read()


class Migration(migrations.Migration):

    dependencies = [
        ('maccman', '0001_initial'),
    ]

    operations = [
        migrations.RunSQL(load_views())
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-07-03 11:20
from __future__ import unicode_literals

import cryptofield.fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Alias',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('account', models.CharField(max_length=249)),
                ('enabled', models.BooleanField(default=True)),
            ],
            options={
                'verbose_name_plural': 'aliases',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Domain',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=252, unique=True)),
                ('enabled', models.BooleanField(default=True)),
            ],
        ),
        migrations.CreateModel(
            name='Mailbox',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('account', models.CharField(max_length=249)),
                ('enabled', models.BooleanField(default=True)),
                ('password', cryptofield.fields.CryptoField(max_length=256)),
                ('domain', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='maccman.Domain')),
            ],
            options={
                'verbose_name_plural': 'mailboxes',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Target',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('address', models.CharField(max_length=254, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name='UserProfile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('allowed_domains', models.ManyToManyField(blank=True, db_table='maccman_users_domains', to='maccman.Domain')),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.AddField(
            model_name='mailbox',
            name='profile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='maccman.UserProfile'),
        ),
        migrations.AddField(
            model_name='domain',
            name='owner',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='maccman.UserProfile'),
        ),
        migrations.AddField(
            model_name='alias',
            name='domain',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='maccman.Domain'),
        ),
        migrations.AddField(
            model_name='alias',
            name='profile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='maccman.UserProfile'),
        ),
        migrations.AddField(
            model_name='alias',
            name='targets',
            field=models.ManyToManyField(db_table='maccman_aliases_targets', to='maccman.Target'),
        ),
        migrations.AlterUniqueTogether(
            name='mailbox',
            unique_together=set([('account', 'domain')]),
        ),
        migrations.AlterUniqueTogether(
            name='alias',
            unique_together=set([('account', 'domain')]),
        ),
    ]



from django.db import models
from django.contrib.auth.models import User

from cryptofield import CryptoField

MAX_ADDRESS_LENGTH = 253
MIN_ACCOUNT_LENGTH = 1
MIN_DOMAIN_LENGTH = 4
MAX_ACCOUNT_LENGTH = MAX_ADDRESS_LENGTH - MIN_DOMAIN_LENGTH
MAX_DOMAIN_LENGTH = MAX_ADDRESS_LENGTH - MIN_ACCOUNT_LENGTH


class Domain(models.Model):
    name = models.CharField(unique=True, max_length=MAX_DOMAIN_LENGTH)
    owner = models.ForeignKey('UserProfile', on_delete=models.CASCADE)
    enabled = models.BooleanField(default=True)

    def __str__(self):
        return self.name


class Target(models.Model):
    address = models.CharField(unique=True, max_length=MAX_ADDRESS_LENGTH + 1)

    def __str__(self):
        return self.address


class UserProfile(models.Model):
    user = models.OneToOneField(User)
    allowed_domains = models.ManyToManyField(Domain,
                                             db_table="mailman_users_domains",
                                             blank=True)

    def __str__(self):
        return "{0} {1} ({2})".format(self.user.first_name,
                                      self.user.last_name,
                                      self.user.username)


class Identity(models.Model):
    account = models.CharField(max_length=MAX_ACCOUNT_LENGTH)
    enabled = models.BooleanField(default=True)
    profile = models.ForeignKey(UserProfile, on_delete=models.CASCADE)
    domain = models.ForeignKey(Domain)

    class Meta:
        unique_together = ('account', 'domain',)
        abstract = True

    def __str__(self):
        return "{0}@{1}".format(self.account, self.domain)


class Mailbox(Identity):
    password = CryptoField()

    class Meta(Identity.Meta):
        verbose_name_plural = "mailboxes"

    def __str__(self):
        return "Mailbox " + super(Mailbox, self).__str__()


class Alias(Identity):
    targets = models.ManyToManyField(Target,
                                     db_table="mailman_aliases_targets")

    class Meta(Identity.Meta):
        verbose_name_plural = "aliases"

    def __str__(self):
        return "Alias " + super(Alias, self).__str__()
